@@ -17,10 +17,12 @@ package aws
 import (
 	"context"
 	"encoding/json"
+	"errors"
 
 	"github.com/GoogleCloudPlatform/terraformer/terraformutils"
 	"github.com/aws/aws-sdk-go-v2/aws"
 	"github.com/aws/aws-sdk-go-v2/service/lambda"
+	"github.com/aws/smithy-go"
 )
 
 var lambdaAllowEmptyValues = []string{"tags."}
@@ -106,30 +108,36 @@ func (g *LambdaGenerator) addFunctions(svc *lambda.Client) error {
 			})
 
 			if err != nil {
-				return err
+				// skip ResourceNotFoundException, because there may be only inline policy defined
+				var apiErr smithy.APIError
+				if !errors.As(err, &apiErr) || apiErr.ErrorCode() != "ResourceNotFoundException" {
+					return err
+				}
 			}
 
-			outputPolicy := *gp.Policy
-			var policy Policy
-			err = json.Unmarshal([]byte(outputPolicy), &policy)
+			if gp != nil {
+				outputPolicy := *gp.Policy
+				var policy Policy
+				err = json.Unmarshal([]byte(outputPolicy), &policy)
 
-			if err != nil {
-				return err
-			}
+				if err != nil {
+					return err
+				}
 
-			for _, statement := range policy.Statement {
-				g.Resources = append(g.Resources, terraformutils.NewResource(
-					statement.Sid,
-					statement.Sid,
-					"aws_lambda_permission",
-					"aws",
-					map[string]string{
-						"statement_id":  statement.Sid,
-						"function_name": *function.FunctionArn,
-					},
-					lambdaAllowEmptyValues,
-					map[string]interface{}{},
-				))
+				for _, statement := range policy.Statement {
+					g.Resources = append(g.Resources, terraformutils.NewResource(
+						statement.Sid,
+						statement.Sid,
+						"aws_lambda_permission",
+						"aws",
+						map[string]string{
+							"statement_id":  statement.Sid,
+							"function_name": *function.FunctionArn,
+						},
+						lambdaAllowEmptyValues,
+						map[string]interface{}{},
+					))
+				}
 			}
 
 			pi := lambda.NewListFunctionEventInvokeConfigsPaginator(svc,
