@@ -18,8 +18,9 @@ func (g SecurityCenterSubscriptionPricingGenerator) listSubscriptionPricing() ([
 	var resources []terraformutils.Resource
 	ctx := context.Background()
 	subscriptionID := g.Args["config"].(authentication.Config).SubscriptionID
+	resourceManagerEndpoint := g.Args["config"].(authentication.Config).CustomResourceManagerEndpoint
 
-	securityCenterPricingClient := security.NewPricingsClient(subscriptionID, "")
+	securityCenterPricingClient := security.NewPricingsClientWithBaseURI(resourceManagerEndpoint, subscriptionID, "")
 	securityCenterPricingClient.Authorizer = g.Args["authorizer"].(autorest.Authorizer)
 
 	if rg := g.Args["resource_group"].(string); rg != "" {
