@@ -16,8 +16,10 @@ package github
 
 import (
 	"context"
+	"net/http"
 
 	"github.com/GoogleCloudPlatform/terraformer/terraformutils"
+	"github.com/bradleyfalzon/ghinstallation/v2"
 	"github.com/google/go-github/v35/github"
 	"golang.org/x/oauth2"
 )
@@ -37,6 +39,13 @@ func (g *GithubService) createClient() (*github.Client, error) {
 
 func (g *GithubService) createRegularClient() *github.Client {
 	ctx := context.Background()
+	if g.Args["app_id"].(int64) != 0 && g.Args["installation_id"].(int64) != 0 && g.Args["pem"].(string) != "" {
+		itr, err := ghinstallation.New(http.DefaultTransport, g.Args["app_id"].(int64), g.Args["installation_id"].(int64), []byte(g.Args["pem"].(string)))
+		if err != nil {
+			return nil
+		}
+		return github.NewClient(&http.Client{Transport: itr})
+	}
 	ts := oauth2.StaticTokenSource(
 		&oauth2.Token{AccessToken: g.Args["token"].(string)},
 	)
@@ -46,10 +55,17 @@ func (g *GithubService) createRegularClient() *github.Client {
 
 func (g *GithubService) createEnterpriseClient() (*github.Client, error) {
 	ctx := context.Background()
+	baseURL := g.GetArgs()["base_url"].(string)
+	if g.Args["app_id"].(int64) != 0 && g.Args["installation_id"].(int64) != 0 && g.Args["pem"].(string) != "" {
+		itr, err := ghinstallation.New(http.DefaultTransport, g.Args["app_id"].(int64), g.Args["installation_id"].(int64), []byte(g.Args["pem"].(string)))
+		if err != nil {
+			return nil, err
+		}
+		return github.NewEnterpriseClient(baseURL, baseURL, &http.Client{Transport: itr})
+	}
 	ts := oauth2.StaticTokenSource(
 		&oauth2.Token{AccessToken: g.Args["token"].(string)},
 	)
 	tc := oauth2.NewClient(ctx, ts)
-	baseURL := g.GetArgs()["base_url"].(string)
 	return github.NewEnterpriseClient(baseURL, baseURL, tc)
 }
