@@ -12,11 +12,17 @@ const (
 	IonosDebug   = "IONOS_DEBUG"
 	Ionos        = "ionoscloud"
 	DcID         = "datacenter_id"
+	ClusterID    = "cluster_id"
 	ServerID     = "server_id"
 	NicID        = "nic_id"
 	K8sClusterID = "k8s_cluster_id"
+	UserID       = "user_id"
+	GroupID      = "group_id"
+	ResourceID   = "resource_id"
+	ZoneID       = "zone_id"
 
 	UsernameArg = "username"
+	NameArg     = "name"
 	PasswordArg = "password"
 	TokenArg    = "token"
 	URLArg      = "url"
