@@ -9,20 +9,16 @@ import (
 	mgo "github.com/Myra-Security-GmbH/myrasec-go/v2"
 )
 
-//
 // MyrasecService ...
-//
 type MyrasecService struct {
 	terraformutils.Service
 }
 
-//
 // initializeAPI ...
-//
 func (s *MyrasecService) initializeAPI() (*mgo.API, error) {
 	apiKey := os.Getenv("MYRASEC_API_KEY")
 	apiSecret := os.Getenv("MYRASEC_API_SECRET")
-	apiUrl := os.Getenv("MYRASEC_API_BASE_URL")
+	apiURL, urlPresent := os.LookupEnv("MYRASEC_API_BASE_URL")
 
 	if apiKey == "" || apiSecret == "" {
 		err := errors.New("missing API credentials")
@@ -31,7 +27,9 @@ func (s *MyrasecService) initializeAPI() (*mgo.API, error) {
 	}
 
 	api, err := mgo.New(apiKey, apiSecret)
-	api.BaseURL = apiUrl
+	if urlPresent {
+		api.BaseURL = apiURL
+	}
 	api.EnableCaching()
 	api.SetCachingTTL(3600)
 
