@@ -2,6 +2,7 @@ package opsgenie
 
 import (
 	"github.com/opsgenie/opsgenie-go-sdk-v2/client"
+	"github.com/opsgenie/opsgenie-go-sdk-v2/service"
 	"github.com/opsgenie/opsgenie-go-sdk-v2/team"
 	"github.com/opsgenie/opsgenie-go-sdk-v2/user"
 
@@ -19,3 +20,7 @@ func (s *OpsgenieService) UserClient() (*user.Client, error) {
 func (s *OpsgenieService) TeamClient() (*team.Client, error) {
 	return team.NewClient(&client.Config{ApiKey: s.GetArgs()["api-key"].(string)})
 }
+
+func (s *OpsgenieService) ServiceClient() (*service.Client, error) {
+	return service.NewClient(&client.Config{ApiKey: s.GetArgs()["api-key"].(string)})
+}
