@@ -15,6 +15,8 @@
 package panos
 
 import (
+	"errors"
+
 	"github.com/GoogleCloudPlatform/terraformer/terraformutils"
 )
 
@@ -25,7 +27,11 @@ type PanosService struct { //nolint
 }
 
 func (p *PanosService) Initialize() error {
-	p.vsys = p.Args["vsys"].(string)
+	if _, ok := p.Args["vsys"].(string); ok {
+		p.vsys = p.Args["vsys"].(string)
+	} else {
+		return errors.New(p.GetName() + ": " + "vsys name not parsable")
+	}
 
 	c, err := Initialize()
 	if err != nil {
