@@ -19,7 +19,6 @@ import (
 	"os"
 
 	"github.com/GoogleCloudPlatform/terraformer/terraformutils"
-	"github.com/GoogleCloudPlatform/terraformer/terraformutils/providerwrapper"
 	"github.com/tencentcloud/tencentcloud-sdk-go/tencentcloud/common"
 	"github.com/tencentcloud/tencentcloud-sdk-go/tencentcloud/common/profile"
 	"github.com/zclconf/go-cty/cty"
@@ -60,6 +59,10 @@ func (p *TencentCloudProvider) GetName() string {
 	return "tencentcloud"
 }
 
+func (p *TencentCloudProvider) GetSource() string {
+	return "tencentcloudstack/" + p.GetName()
+}
+
 func (p *TencentCloudProvider) Init(args []string) error {
 	err := p.getCredential()
 	if err != nil {
@@ -111,6 +114,10 @@ func (p *TencentCloudProvider) GetSupportedService() map[string]terraformutils.S
 		"route_table":    &RouteTableGenerator{},
 		"nat_gateway":    &NatGatewayGenerator{},
 		"acl":            &ACLGenerator{},
+		"pts":            &PtsGenerator{},
+		"tat":            &TatGenerator{},
+		"dnspod":         &DnspodGenerator{},
+		"ses":            &SesGenerator{},
 	}
 }
 
@@ -196,7 +203,7 @@ func (p *TencentCloudProvider) GetProviderData(arg ...string) map[string]interfa
 	return map[string]interface{}{
 		"provider": map[string]interface{}{
 			p.GetName(): map[string]interface{}{
-				"version": providerwrapper.GetProviderVersion(p.GetName()),
+				"region": p.region,
 			},
 		},
 	}
